@@ -864,7 +864,7 @@ class Askdata(SignUp):
             for condition in join_conditions:
                 left_conditions.append(condition["left_on"])
                 right_conditions.append(condition["right_on"])
-            return df.merge(df_query, how, '', left_conditions, right_conditions)
+            return df.merge(df_query, how, None, left_conditions, right_conditions)
 
         return df.merge(df_query, how, on, left_on, right_on)
 
